@@ -1,6 +1,6 @@
 package App::cdif::Tmpfile;
 
-use strict;
+use v5.14;
 use warnings;
 use utf8;
 use Carp;
